package tree;

/*
 * HTMessage.java
 *
 * The MIT License :
 * -----------------
 * Copyright (c) 2005 Embrapa Informtica Agropecuria
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
 * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import java.awt.*;
import java.awt.event.*;

public class HTDialogYesNo extends Dialog {

  static private boolean answer = false;
  Button yes, no, cancel; 

  public HTDialogYesNo(Frame parent, String title, String message,
                     String yes_label, String no_label, String cancel_label)
  {
    // Create a modal dialog with the specified title and parent
    super(parent, title, true);

    // Specify a LayoutManager for it
    this.setLayout(new BorderLayout(15, 15));

    // Put the message label in the middle of the window.
    // Note: MultiLineLabel is a custom component defined later in the chapter
    this.add("Center", new Label(message));

    // Create an action listener for use by the buttons of the dialog.
    // When a button is pressed, this listener first closes the dialog box.
    // Then, it passes the event on to the listeners registered for the
    // dialog box, after changing the event source from the individual button
    // to the dialog box itself.  Since events are immutable, it must create
    // a new ActionEvent object in order to change the source.  It passes
    // this new event to the listeners by calling actionPerformed() on the
    // AWTEventMulticaster object stored in the listeners field (see below).
    ActionListener listener = new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        HTDialogYesNo.this.dispose();   // pop down dialog
        if (listeners != null)        // notify all registered listeners
          listeners.actionPerformed(new ActionEvent(HTDialogYesNo.this,
                                                    e.getID(),
                                                    e.getActionCommand()));
      }
    };

    // Create a panel for the dialog buttons and put it at the bottom
    // of the dialog.  Specify a FlowLayout layout manager for it.
    Panel buttonbox = new Panel();
    buttonbox.setLayout(new FlowLayout(FlowLayout.CENTER, 25, 15));
    this.add("South", buttonbox);

    // Create each specified button, specifying the action listener
    // and action command for each, and adding them to the buttonbox
    if (yes_label != null) {              // if a label was specified...
      yes = new Button(yes_label);     //   create button
      yes.setActionCommand("yes");            //   set action command
      yes.addActionListener(listener);        //   set listener
      buttonbox.add(yes);                     //   add button to the panel
    }
    if (no_label != null) {
      no = new Button(no_label);
      no.setActionCommand("no");
      no.addActionListener(listener);
      buttonbox.add(no);
    }
    if (cancel_label != null) {
      cancel = new Button(cancel_label);
      cancel.setActionCommand("cancel");
      cancel.addActionListener(listener);
      buttonbox.add(cancel);
    }

    // Finally, set the dialog to its preferred size.
    this.pack();
  }

  /** This field will hold a list of registered ActionListeners, thanks
   *  to the magic of AWTEventMulticaster */
  protected ActionListener listeners = null;

  /** Register an action listener to be notified when a button is pressed
   *  AWTEventMulticaster makes this easy. */
  public void addActionListener(ActionListener l) {
    listeners = AWTEventMulticaster.add(listeners, l);
  }

  /** Remove an action listener from our list of interested listeners */
  public void removeActionListener(ActionListener l) {
    listeners = AWTEventMulticaster.remove(listeners, l);
  }

   public boolean getAnswer() {
	return answer;
   }

}
